@@ -1,8 +1,8 @@
 # -*- coding:utf-8 -*-
 """
 Author:Jy
-2020/7/20 17:56:00
-ningbo
+2020/09/09 11:56:00
+shanghai
 """
 import sys, os
 sys.path.append(os.path.dirname(os.path.abspath(__file__))+'\\common')
@@ -29,20 +29,47 @@ class JyInterface(object):
     def sleep(self, n):
         time.sleep(n)
     
-    def logPrint(self, msg):
+    def logPrint(self, *args):
         try:
+            print(*args)
+            msg = ''
+            for v in args:
+                msg = msg + str(v)
             self.stub.addTradeLog(common_pb2.LogRequest(transferId=self.transferId,
                                                         msg=msg))
         except:
-            print(msg)
-
+            pass
+ 
     def stopStrategy(self):
         try:
-            self.stub.stopStrategy(common_pb2.StopRequest(transferId=self.transferId)) 
+            output = self.stub.stopStrategy(common_pb2.StopRequest(transferId=self.transferId)) 
+            if output.message == 'false':
+                sys.exit(0)
+            return output.message
         except:
-            print('------stopStrategy------')
-            sys.exit(0)    
-
+            self.logPrint('------stopStrategy------')
+            sys.exit(0)
+ 
+    
+    def getCapital(self, symbol:str, choice:int=0):
+        if self.futureOrSpot == 1:
+            response = self.stub.getCapital(common_pb2.CapitalRequest(type=self.type_,
+                                                                 appKey=self.appKey,
+                                                                 secret=self.secret,
+                                                                 passphrase=self.passphrase,
+                                                                 futureOrSpot=self.futureOrSpot,
+                                                                 symbols=symbol))   
+        else:
+            symstr = symbol.split('/', 1)[choice]
+            response = self.stub.getCapital(common_pb2.CapitalRequest(type=self.type_,
+                                                                 appKey=self.appKey,
+                                                                 secret=self.secret,
+                                                                 passphrase=self.passphrase,
+                                                                 futureOrSpot=self.futureOrSpot,
+                                                                 symbols=symstr))              
+        
+        return ast.literal_eval(response.message.replace('null','"null"'))
+    
     def getKline(self, symbol, klinePeriod, size):
         pType = "" # fixed return all 
         response = self.stub.getKline(common_pb2.KlineRequest(type=self.type_,
@@ -125,7 +152,6 @@ class JyInterface(object):
                                                                        symbols=symbol,
                                                                        orderId=orderId,
                                                                        appKey=self.appKey,
-                   
                                                                        secret=self.secret,
                                                                        passphrase=self.passphrase,
                                                                        futureOrSpot=self.futureOrSpot))
@@ -154,7 +180,7 @@ class JyInterface(object):
             return output[0]
         else:
             response = self.stub.getPosition(common_pb2.BalanceRequest(type=self.type_,
-                                                                                   appKey=self.appKey,
+                                                                         appKey=self.appKey,
                                                                          secret=self.secret,
                                                                          passphrase=self.passphrase,
                                                                          futureOrSpot=self.futureOrSpot,
@@ -164,6 +190,8 @@ class JyInterface(object):
                 return output[1]
             elif x == 'short': 
                 return output[2]
+            elif x == 'Margin':
+                return output[0]
      
     def getMargin(self, symbol:str):
         response = self.stub.getPosition(common_pb2.BalanceRequest(type=self.type_,
@@ -229,10 +257,23 @@ class JyInterface(object):
             elif tmstr[0] == 'm' and (tm.tm_min % tmnum != 0 or tm.tm_sec != 0):
                 return
             elif tmstr[0] == 'd' and (tm.tm_hour != 0 or tm.tm_min != 0 or tm.tm_sec != 0):
-                return
+                return            
             self.loop()
-        except:
-            pass
+        except Exception:
+            if Exception == 'SystemExit':
+                sys.exit(0)
+            else:
+                pass
+    
+    def run2_(self, *args):
+        """let subclass inherit"""
+        try:         
+            self.loop2(*args)
+        except Exception:
+            if Exception == 'SystemExit':
+                sys.exit(0)
+            else:
+                pass
 
     def run(self, func):
         while True:
@@ -250,5 +291,8 @@ class JyInterface(object):
                 elif tmstr[0] == 'd' and (tm.tm_hour != 0 or tm.tm_min != 0 or tm.tm_sec != 0):
                     continue
                 func()
-            except:
-                pass
\ No newline at end of file
+            except Exception:
+                if Exception == 'SystemExit':
+                    sys.exit(0)
+                else:
+                    pass
\ No newline at end of file
